@@ -281,6 +281,40 @@ class SQLExecute(object):
                                         if str(result[j]) > str(result[j + 1]):
                                             result[j], result[j + 1] = result[j + 1], result[j]
 
+                            if "SQLCLI_DEBUG" in os.environ:
+                                # DEBUG模式下不会过滤任何东西
+                                pass
+                            else:
+                                # 如果Hint中存在LogFilter，则过滤指定的输出信息
+                                if "LogFilter" in m_SQLHint.keys() and result is not None:
+                                    for m_SQLFilter in m_SQLHint["LogFilter"]:
+                                        for item in result[:]:
+                                            if re.match(m_SQLFilter, ''.join(str(item)), re.IGNORECASE):
+                                                result.remove(item)
+                                                continue
+
+                                # 如果Hint中存在LogMask,，则掩码指定的输出信息
+                                if "LogMask" in m_SQLHint.keys() and result is not None:
+                                    for i in range(0, len(result)):
+                                        m_Output = None
+                                        for j in range(0, len(result[i])):
+                                            if m_Output is None:
+                                                m_Output = str(result[i][j])
+                                            else:
+                                                m_Output = m_Output + "," + str(result[i][j])
+                                        for m_SQLMaskString in m_SQLHint["LogMask"]:
+                                            m_SQLMask = m_SQLMaskString.split("=>")
+                                            if len(m_SQLMask) == 2:
+                                                m_SQLMaskPattern = m_SQLMask[0]
+                                                m_SQLMaskTarget = m_SQLMask[1]
+                                                m_NewOutput = re.sub(m_SQLMaskPattern, m_SQLMaskTarget, m_Output,
+                                                                     re.IGNORECASE)
+                                                if m_NewOutput != m_Output:
+                                                    result[i] = tuple(m_NewOutput.split(','))
+                                            else:
+                                                if "SQLCLI_DEBUG" in os.environ:
+                                                    raise SQLCliException("LogMask Hint Error: " + m_SQLHint["LogMask"])
+
                             # 返回SQL结果
                             if self.SQLOptions.get('TERMOUT').upper() != 'OFF':
                                 yield title, result, headers, columntypes, status
@@ -463,7 +497,7 @@ class SQLExecute(object):
                 # 如果文件不存在，创建文件，并写入文件头信息
                 self.SQLPerfFileHandle = open(self.SQLPerfFile, "a", encoding="utf-8")
                 self.SQLPerfFileHandle.write("Script\tStarted\telapsed\tRAWSQL\tSQL\t"
-                                             "SQLStatus\tErrorMessage\tthread_name\t"
+                                             "SQLStatus\tErrorMessage\tworker_name\t"
                                              "Scenario\tTransaction\n")
                 self.SQLPerfFileHandle.close()
 
@@ -479,16 +513,16 @@ class SQLExecute(object):
             else:
                 m_SQL_Script = str(os.path.basename(self.sqlscript))
             self.SQLPerfFileHandle.write(
-                "'" + m_SQL_Script + "'\t" +
-                "'" + time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(p_SQLResult["StartedTime"])) + "'\t" +
+                m_SQL_Script + "\t" +
+                time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(p_SQLResult["StartedTime"])) + "\t" +
                 "%8.2f" % p_SQLResult["elapsed"] + "\t" +
-                "'" + str(p_SQLResult["RAWSQL"]).replace("\n", " ").replace("\t", "    ") + "'\t" +
-                "'" + str(p_SQLResult["SQL"]).replace("\n", " ").replace("\t", "    ") + "'\t" +
+                str(p_SQLResult["RAWSQL"]).replace("\n", " ").replace("\t", "    ") + "\t" +
+                str(p_SQLResult["SQL"]).replace("\n", " ").replace("\t", "    ") + "\t" +
                 str(p_SQLResult["SQLStatus"]) + "\t" +
-                "'" + str(p_SQLResult["ErrorMessage"]).replace("\n", " ").replace("\t", "    ") + "'\t" +
-                "'" + str(m_ThreadName) + "'\t" +
-                "'" + str(p_SQLResult["Scenario"]) + "'\t" +
-                "'" + str(p_SQLResult["Transaction"]) + "'" +
+                str(p_SQLResult["ErrorMessage"]).replace("\n", " ").replace("\t", "    ") + "\t" +
+                str(m_ThreadName) + "\t" +
+                str(p_SQLResult["Scenario"]) + "\t" +
+                str(p_SQLResult["Transaction"]) +
                 "\n"
             )
             self.SQLPerfFileHandle.flush()
